@@ -38,7 +38,7 @@ def key(method, len, convert, verbose):
             click.echo(text)
     echo("method:{}, len:{}, convert:{}, verbose:{}".format(method, len, convert, verbose))
     method_dict = {
-        "md5": lambda : raw_md5("{}".format(time.time()))
+        "md5": lambda : raw_md5("{}".format(time.time()).encode("utf-8"))
     }
     raw_result = method_dict[method]()
     raw_result = raw_result[:len]
@@ -46,7 +46,7 @@ def key(method, len, convert, verbose):
         "lower": lambda x :x.lower(),
         "upper": lambda x: x.upper()
     }
-    result =  convert_dict[convert][raw_result]
+    result =  convert_dict[convert](raw_result)
     click.echo("key:{}".format(result))
 
 @click.command()
